---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "HellFortressTwo.ogg",
voice_acting = "GameLost.ogg",
preroll_text = 3,
postroll_text = 3,
text = [[
            Prohráls. Hra byla ztracena.

Zkus to prosím znovu, a pokud tak učiníš, ujisti se, že od našich sponzorů koupíš:

Dr. Jak - "Mocná pohodlná technologie!"

Kan4dská l3kárna - "Úžasný průlom bylinných přípr4vků! Garantování 100% spokoj3nosti!!!"

KryoniK Řešení - "Vemte to rychlou cestu do budoucnosti s KryoniK Řešením!"

Budoucí Balistiky - "Za hranice balistiky. Budoucí Balistiky."

MegaSystémy - "Co nechceš dnes dělat?"

Odstraňování odpadků Masternak - "ODSTRAŇUJEM tvé ODPADKY."

Nicholsonovy závody - "Bezpečnost v plné síle."

Rudé Slunce - "Noc je u konce: ochutnej úsvit!"



Zkus to prosím znovu. Pro pokračování klikni.
]]
}
