---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
background = "credits.jpg",
song = "TheBeginning.ogg",
text = [[
            CÓMO CONTRIBUIR

FreedroidRPG es enteramente software libre y arte gratuito.
Es exclusivamente desarrollado por voluntarios en sus tiempos de ocio.

FreedroidRPG depende de estos contribuidores para convertirse en un mejor juego.
Si te gustaría contribuir algo, pero no estas completamente seguro de como, aquí hay una lista de cosas:

TESTEO Y REPORTAJE DE BUGS:

Necesitamos gente para que prueben el juego y reporten cualquier cosa que no funcione correctamente o parezca inestable. Esto incluye cosas menores, como errores de ortografía y similares. La tarea de testear crece junto el tamaño de FreedroidRPG. Necesitamos tu ayuda.
¡No dudes en enviar parches!

CREACIÓN DE MAPAS:

Estamos buscando a gente que le gustaría hacer mapas por nosotros. Hay un editor de mapas dentro del juego. Pruebalo, y si haces algo interesante asegurate de contactarnos.

DOCUMENTACIÓN:

Actualmente estamos faltos de documentación. Necesitaríamos documentación para usuarios con relación al juego y su editor de niveles, al igual que documentación dirigida a desarrolladores. Buenas habilidades de escritura requeridas.

EFECTOS DE SONIDO:

Desde luego podríamos usar algunos efectos de sonido. Si quieres contribuir algunos a una buena causa no te diremos que no lo hagas. :)

CONTACTO:

Si te gustaría contribuir algo o darnos alguna opinión acerca del juego, puedes ponerte en contacto fácilmente con los desarrolladores. Solo enviá un e-mail a estas siguientes direcciones:
freedroid-discussion@lists.sourceforge.net

Or, if you prefer, you might want to pop into our IRC channel (#freedroid on irc.libera.chat). Everyone's invited. Bring your friends!

Gracias.

            El equipo de desarrollo de FreedroidRPG.
]]
}
