---------------------------------------------------------------------
--
--  Copyright (c) 2002, 2003 Johannes Prix
--
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
background = "credits.jpg",
song = "HellFortressTwo.ogg",
text = [[
Tu t'amuses ?
Non

Les robots semblent vraiment énervés par quelquechose.
Je suppose qu'ils sont en colère contre toi.
Au moins, ils ne me cherchent plus. 
C'est comme une ?relève?

Je suis sûr que tu meures d'envie de me parler. 
Je pense à quelque-chose.
Pour l'instant tu ne peux qu'écouter. 
Désormais, tu devras vivre avec ça. 

Notre chef a eu le cerveau grillé.
Ça veut dire que je prends les commandes.
J'en ai un peu marre.
Je déteste ce monde.
On va partir d'ici.

J'ai trouvé Azerty, mais ça ne veut rien dire.
Sa température interne est au dessus du point de congélation.
Autrement dit, il est mort. 
Il ne me manquera pas. 

Je n'arrive pas à trouver Arensito. 
J'espère qu'elle va bien.
Je suis ?inquiet? à son sujet.
Nous n'avons pas besoin d'Azerty.
Mais nous avons besoin d'Arensito.
Je vais continuer à la chercher.

Il y a une I.A. dans ta région.
Elle s'appelle elle-même la “Singularité”.  
Ou quelque-chose comme ça.
Je ne comprends pas ce qu'elle veut. 
Je te tiendrais au courant..

Ah, et au fait...
Les robots sont en train de tuer tout le monde dans la petite ville d'à côté.
Vraiment, une vision d'horreur. Ils brulent tout.
La Garde Rouge de la citadelle tient encore bon. 
Pour l'instant. 
Tu ferais mieux de te cacher pendant qu'ils démolissent l'endroit.
D'ici quelques heures, il devrait être possible d'y retourner.

Je pense que j'ai tout dit.
Je vais aller préparer mon départ maintenant.
Tu devrais faire pareil.
Nous devons trouver Arensito.
Elle nous sortira de là.

Dvorak, Première IA.



À suivre...



Quelques mots de l'équipe de développement de FreedroidRPG :

Nous espérons que tu as apprécié notre jeu.

Si tu à envie d'y ajouter quelque chose, tu seras le bienvenu. Il y a plein de possibilités. Nous recherchons en particulier du contenu supplémentaire, c'est-à-dire :

* de nouveaux embellissements des cartes
* des idées de nouvelles cartes
* toute autre chose auquel tu pourrais penser

Voir également la section 'Contribution'.

L'équipe de développement de FreedroidRPG.


Presser Feu pour continuer.
]]
}
