---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "HellFortressTwo.ogg",
voice_acting = "GameLost.ogg",
preroll_text = 3,
postroll_text = 3,
text = [[
            Spelet Förlorat

Var vänlig försök igen, och när du gör det, se till att köpa något av våra sponsorer:

Dr. Hur - "Mäkta bekväm teknologi!"

Det Kan4d3ns1ska 4p0t3ket - "Fantastiska genombrott inom örtläkem3del! Garanterar 100% belåtenh3t!!!"

Kryo-Hjälpen - "Ta en snabb resa in i framtiden med Kryo-Hjälpen!"

Framtida Sprängmedel AB - "Bortom sprängmedel. Framtida Sprängmedel."

MegaSystems - "Vad vill du inte göra idag?"

Masternaks Skäpborttagning - "Vi KROSSAR ditt SKRÄP"

Nicholson AB - "Säkerhet med hämd"

Röda Solen - "Natten är över: smaka på gryningen!"



Var vänlig försök igen. Klicka för att fortsätta.
]]
}
