---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "TheBeginning.ogg",
text = [[
Försöker hacka någon, va?
Kommer inte ihåg hur man gjorde?
Idiot. Grilla inte din hjärna och försök hacka något.
Här kommer en snabbkurs för att fräscha upp ditt minne.

För det första, hacka inte när du är på väg att dö.
Om du misslyckas får du en elektrisk chock.
Det är inte dödligt, om du inte är allvarligt skadad, men det gör ont.
Mycket.

Hackning består av två steg.
Välj först det kretskort du tycker ser bäst ut.
Ett är gult och det andra rött.
Välj helt enkelt med höger- eller vänsterknapp.
Du har på dig 10 sekunder innan botten upptäcker dig.
Välj det kretskort som ger dig ett övertag.

Det andra steget är att skapa anslutningar till kärnorna.
Där sakerna i mitten, om du undrar.

Eftersom bottar är fulla av buggar, kommer vissa kärnor vara på din sida.
Du kan bara göra några få attacker, så gör dem med eftertanke.
Välj vilken ledning du vill attackera kärnorna med.
Använd piltangenterna för gå upp eller ner.
Eller så kan du använda mushjulet, om du har ett.
När du valt trycker du på mellanslag.
Allt som är i andra ändan av ledningen blir ditt.
Självklart kommer botten inte bara sitta där med armarna i kors.
Den kommer försöka få tillbaka kontrollen och göra sina egna anslutningar.

Och efter en stund är allt över.
Om du kontrollerar flest kärnor då, är botten din.
Om inte, får du en gratis elchock. På MegaSys sätt.

Ibland är ledningarna i botten en enda röra.
Du får lära dig hur det fungerar på egen hand.
Jag tänker inte riskera något för din skull.
Det är för många bottar för att sända någon längre stund.

Åh, jag vill be dig om något.
Nästa gång du tänker woka hjärnan...
Ta med dig manualerna in i djupsömnen.
Jag kanske inte finns där för att hjälpa dig nästa gång.

            Dvorak, Förste AI.
]]
}
