
difficulties
{
	-- easy
	{
		droid_max_speed = 0.4,
		droid_hpmax = 1.0,
		droid_hostile_healing = 0.0,
		droid_friendly_healing = 0.1,
		droid_experience_reward = 1.2,
		droid_aggression_distance = 0.75,
	},
	-- normal
	{
		droid_max_speed = 0.5,
		droid_hpmax = 1.0,
		droid_hostile_healing = 0.05,
		droid_friendly_healing = 0.05,
		droid_experience_reward = 1.0,
		droid_aggression_distance = 1.0,
	},
	-- hard
	{
		droid_max_speed = 0.6,
		droid_hpmax = 1.5,
		droid_hostile_healing = 0.1,
		droid_friendly_healing = 0.05,
		droid_experience_reward = 1.0,
		droid_aggression_distance = 1.25,
	},
}
