---------------------------------------------------------------------
--
--  Copyright (c) 2002, 2003 Johannes Prix
--
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
background = "credits.jpg",
song = "HellFortressTwo.ogg",
voice_acting = "EndOfAct.ogg",
preroll_text = 2,
postroll_text = 5,
text = [[
    Se divertindo?
  Eu não.

Os robôs parecem perturbados com alguma coisa.
Suponho que estejam com raiva de você.
Mas pelo menos pararam de me procurar.
Aliviador? Não?

Tem um IA na sua região.
Chama a si mesmo de "Singularidade".
Ou algo assim.
Eu não consigo entender o que ele quer.
Lhe manterei informado.

Oh, e por falar nisso...
Eu ainda estou te esperando.
Eu não me movi um palmo desde que você acordou.
Agora que sua amada cidade está salva...
...Não seria uma boa hora para me salvar também?

            Dvorak, Primeiro IA.



=== FIM DO PRIMEIRO ATO ===

]]
}
