---------------------------------------------------------------------
--
--  Copyright (c) 2002, 2003 Johannes Prix
--  Copyright (c) 2003 Pete Spicer
--
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "Bleostrada.ogg",
text = [[
            CONTROLES

MOVIMIENTO:

El juego se controla usando el ratón. Haz click izquierdo en las zonas a las que quieras moverte. Mantén el botón pulsado para moverte en esa dirección. Manteniendo pulsado la tecla CTRL hará que corras.

ATACAR:

Haciendo click izquierdo sobre un enemigo hará que Tux se acerque al robot y lo ataque con su arma equipada. Si la arma presente es un arma de fuego entonces Tux se quedara quieto y disparara al robot.

FUNCIONES ESPECIALES:

Use el click derecho para activar la habilidad o programa seleccionado.

Teclas por defecto (la mayoria de teclas pueden ser reasignadas con la configuracion de teclas en juego - F1)

  Escape ... Mostrar menú principal
  F1 ... Mostrar configuración de teclas
  F2 ... Cambiar a pantalla completa (sólo Linux)
  F3 ... Salvado rápido
  F4 ... Carga rápida
  F5 a F12 ... Selección rápida de programas 1 a 8

  I ... Panel de inventario
  C ... Panel de personaje
  S ... Panel de Habilidades/Programas
  Espacio ... Cerrar todos los paneles abiertos
  Q ... Registro de misiones
  0 a 9 ... Usar objetos de inventario rápido 0 a 9

  P... Pausa
  Mantener A ... Atacar manteniando la posición
  Mantener Shift ... Mantener el objetivo actual seleccionado moviéndose
  Tab ... Activa el automapa

  R ... Recargar arma
  Mantener Ctrl ... Correr
  U ... Conmutar correr siempre.

  Mantener X ... Mostrar etiquetas de objetos en el suelo
  Z ... Conmutar mostrar etiquetas de objetos en el suelo
  T ... Activa la transparencia de las paredes cuando Tux se acerque (Solo con OpenGL)

CAPTURAR/HABLAR

Para hablar con un droide amistoso, es suficiente pulsar sobre el. Para capturar un robot hostil, selecciona la habilidad capturar/hablar de la pantalla de habilidades, entonces pulsa el botón derecho del ratón para iniciar la captura.

Para el juego de la captura, puedes usar la rueda del ratón o las teclas de cursor.

Quizá te interese jugar el Tutorial el cual puede ser accedido desde el menú principal.

If you are stuck and need help, feel free to come to #freedroid on irc.libera.chat and ask for help.

Eso es todo. ¡Que te diviertas!



Pulsa el botón izquierdo del ratón para empezar a jugar.
]]
}
