---------------------------------------------------------------------
--
--  Copyright (c) 2002, 2003 Johannes Prix
--
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
background = "credits.jpg",
song = "HellFortressTwo.ogg",
voice_acting = "EndOfAct.ogg",
preroll_text = 2,
postroll_text = 5,
text = [[
    Веселишься?
  А я нет.

Боты выглядят чем-то расстроенными.
Думаю, они на тебя злятся.
Они хотя бы перестали искать меня.
Какое «облегчение».

В твоём регионе есть ИИ.
Он сам себя называет «Сингулярностью».
Или что-то вроде того.
Я не понимаю, чего он хочет.
Буду держать тебя в курсе.

О, и кстати...
Я всё ещё жду тебя.
Я не сдвинулся ни на дюйм со времени твоего пробуждения.
Теперь, когда твой любимый город в безопасности...
...Не пора ли также спасти и меня?

            Дворак, первый ИИ.



=== КОНЕЦ ПЕРВОГО ДЕЙСТВИЯ ===

]]
}
