---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
background = "credits.jpg",
song = "TheBeginning.ogg",
text = [[
            HOW TO CONTRIBUTE

FreedroidRPG is entirely free software and free artwork.
It is developed exclusively by volunteers in their leisure time.

FreedroidRPG depends on these contributions to become a better game.
If you would like to contribute something, but are not completely sure how, here's a list of things:

TESTING AND BUG REPORTING:

We need people to try out the game and report anything that does not work correctly or seems to be unstable. This includes minor things, such as spelling mistakes and the like. The task of testing is growing with the size of FreedroidRPG. We need your help.
Don't hesitate to send patches!

MAP MAKING:

We are looking for people who would make maps for us. There is a map editor built into the game. Try it, and if you make something interesting make sure to get back to us.

DOCUMENTATION:

We currently lack documentation. We would need end-user documentation related to the game and its level editor, as well as developer targeted documentation. Good writing skills required.

SOUND EFFECTS:

We sure could use some sound effects. If you want to contribute some to a good cause we will not say no to that. :)

CONTACT:

If you would like to contribute something or give some feedback concerning the game, you can easily get in contact with the developers. Just send an e-mail to the following address:
freedroid-discussion@lists.sourceforge.net

Or, if you prefer, you might want to pop into our IRC channel (#freedroid on irc.libera.chat). Everyone's invited. Bring your friends!

Thank you,

            The FreedroidRPG dev team.
]]
}
