---------------------------------------------------------------------
--
--  Copyright (c) 2002, 2003 Johannes Prix
--
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
background = "credits.jpg",
song = "HellFortressTwo.ogg",
voice_acting = "EndOfAct.ogg",
preroll_text = 2,
postroll_text = 5,
text = [[
    Tu t'amuses ?
  Non

Les robots semblent vraiment énervés par quelquechose.
Je suppose qu'ils sont en colère contre toi.
Au moins, ils ne me cherchent plus. 
Quel soulagement

Il y a une I.A. dans ta région.
Elle s'appelle elle-même la “Singularité”.  
Ou quelque-chose comme ça.
Je ne comprends pas ce qu'elle veut. 
Je te tiendrais au courant..

Ah, et au fait...
Je t'attends toujours
Je n'ai pas bougé d'un iota depuis que tu t'es réveillé
Maintenant que ta ville adorée est sauve ...
Ne serait-il pas temps de me sauver aussi ?

            Dvorak, Première IA.



=== FIN DE L'ACTE 1 ===

]]
}
