---------------------------------------------------------------------
--
--  Copyright (c) 2002, 2003 Johannes Prix
--
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
background = "credits.jpg",
song = "HellFortressTwo.ogg",
voice_acting = "EndOfAct.ogg",
preroll_text = 2,
postroll_text = 5,
text = [[
    Jól szórakozol?
  Én nem.

A botok zaklatottnak tűnnek valami miatt.
Azt hiszem mérgesek rád.
Legalább már engem nem keresnek.
Megnyugtató(?), nem?

Van egy MI a területeden.
„Szingularitásnak” nevezi magát.
Vagy valami ilyesmi.
Nem értem mit akarhat.
Majd tájékoztatlak.

Ó, és egyébként…
Még mindig várok rád.
Egy centit sem mozdultam mióta felkeltél.
Most hogy a kedvelt városod biztonságban van…
…Nincs itt az ideje, hogy engem is megments?

            Dvorak, Első MI



=== VÉGE AZ 1. FELVONÁSNAK ===

]]
}
