leveleditor_obstacle_category {
	name = "WALL",
	obstacles = {
		"iso_pathblocker_1x1.png",
		"iso_gate_unlocked_closed_ns_1.png",
		"iso_gate_unlocked_closed_we_1.png",
		"iso_gate_locked_ns.png",
		"iso_gate_locked_we.png",
		"iso_gate_unlocked_opened_ns_5.png",
		"iso_gate_unlocked_opened_we_5.png",
		"iso_wall_yellow_ellipsis_ns.png",
		"iso_wall_yellow_ellipsis_we.png",
		"iso_wall_yellow_ellipsis_dots_pipes_ns.png",
		"iso_wall_yellow_ellipsis_dots_pipes_we.png",
		"iso_wall_yellow_ellipsis_dots_ns.png",
		"iso_wall_yellow_ellipsis_dots_we.png",
		"iso_walls_yellow_ns.png",
		"iso_walls_yellow_we.png",
		"iso_wall_yellow_dots_pipes_ns.png",
		"iso_wall_yellow_dots_pipes_we.png",
		"iso_wall_yellow_dots_ns.png",
		"iso_wall_yellow_dots_we.png",
		"iso_wall_yellow_curve_long_es.png",
		"iso_wall_yellow_curve_long_ws.png",
		"iso_wall_yellow_curve_long_nw.png",
		"iso_wall_yellow_curve_long_ne.png",
		"iso_wall_yellow_curve_short_es.png",
		"iso_wall_yellow_curve_short_ws.png",
		"iso_wall_yellow_curve_short_nw.png",
		"iso_wall_yellow_curve_short_ne.png",
		"iso_door_unlocked_closed_ns_1.png",
		"iso_door_unlocked_closed_we_1.png",
		"iso_doubledoor_unlocked_opened_ns_1.png",
		"iso_doubledoor_unlocked_opened_we_1.png",
		"iso_door_locked_ns.png",
		"iso_door_locked_we.png",
		"iso_doubledoor_locked_ns.png",
		"iso_doubledoor_locked_we.png",
		"iso_wall_grey_ns.png",
		"iso_wall_grey_ew.png",
		"iso_wall_grey_handle_ns.png",
		"iso_wall_grey_handle_ew.png",
		"iso_wall_grey_window_ns.png",
		"iso_wall_grey_window_ew.png",
		"iso_wall_grey_striation_ns.png",
		"iso_wall_grey_striation_ew.png",
		"iso_wall_red_ns.png",
		"iso_wall_red_we.png",
		"iso_wall_red_window_ns.png",
		"iso_wall_red_window_we.png",
		"iso_wall_turqois_ns.png",
		"iso_wall_turqois_we.png",
		"iso_wall_turquois_window_ns.png",
		"iso_wall_turquois_window_we.png",
		"iso_wall_green_wallpaper_ns.png",
		"iso_wall_green_wallpaper_we.png",
		"iso_wall_green_wallpaper_window_ns.png",
		"iso_wall_green_wallpaper_window_we.png",
		"iso_wall_green_brown_manyspots_ns.png",
		"iso_wall_green_brown_manyspots_we.png",
		"iso_wall_green_brown_fewspots_ns.png",
		"iso_wall_green_brown_fewspots_ew.png",
		"iso_wall_green_brown_manyspots_window_ns.png",
		"iso_wall_green_brown_manyspots_window_we.png",
		"iso_wall_cave_ns.png",
		"iso_wall_cave_we.png",
		"iso_wall_cave_curve_es.png",
		"iso_wall_cave_curve_ws.png",
		"iso_wall_cave_curve_nw.png",
		"iso_wall_cave_curve_ne.png",
		"iso_wall_cave_end_e.png",
		"iso_wall_cave_end_s.png",
		"iso_wall_cave_end_w.png",
		"iso_wall_cave_end_n.png",
		"iso_wall_cave_dark_ns.png",
		"iso_wall_cave_dark_we.png",
		"iso_wall_cave_curve_dark_es.png",
		"iso_wall_cave_curve_dark_nw.png",
		"iso_wall_cave_curve_dark_ne.png",
		"iso_fence_white_ns.png",
		"iso_fence_white_we.png",
		"iso_fence_wire_red_ns.png",
		"iso_fence_wire_red_we.png",
		"iso_fence_wire_green_ns.png",
		"iso_fence_wire_green_we.png",
		"iso_wall_glass_ns.png",
		"iso_wall_glass_broken_ns.png",
		"iso_wall_glass_we.png",
		"iso_wall_glass_broken_we.png",
		"iso_wall_purple_ns.png",
		"iso_wall_purple_we.png",
		"iso_wall_purple_es.png",
		"iso_wall_purple_curve_ws.png",
		"iso_wall_purple_nw.png",
		"iso_wall_purple_ne.png",
		"iso_wall_purple_T_ess.png",
		"iso_wall_purple_T_nwe.png",
		"iso_wall_purple_T_nws.png",
		"iso_wall_purple_T_wes.png",
		"iso_wall_brick_we.png",
		"iso_wall_brick_ns.png",
		"iso_wall_brick_longend_we.png",
		"iso_wall_brick_longend_ns.png",
		"iso_wall_brick_end_w.png",
		"iso_wall_brick_edge_es.png",
		"iso_wall_brick_edge_ws.png",
		"iso_wall_brick_edge_nw.png",
		"iso_wall_brick_edge_ne.png",
		"iso_wall_brick_T_nws.png",
		"iso_wall_brick_T_nwe.png",
		"iso_wall_brick_T_nes.png",
		"iso_wall_brick_T_wes.png",
		"iso_wall_brick_cracked_ns.png",
		"iso_wall_brick_cracked_we.png",
		"iso_wall_brick_smashed_ns.png",
		"iso_wall_brick_smashed_we.png",
		"iso_wall_brick_cable_ns.png",
		"iso_wall_brick_cable_we.png",
		"iso_wall_brick_cable_edge_nw.png",
		"iso_wall_brick_cable_edge_es.png",
		"iso_wall_brick_cable_edge_ne.png",
		"iso_wall_brick_cable_edge_ws.png",
		"iso_wall_redbrownspiked_ns.png",
		"iso_wall_redbrownspiked_we.png",
		"iso_curtain_ns.png",
		"iso_curtain_we.png",
		"iso_wall_corners_es.png",
		"iso_wall_corners_ws.png",
		"iso_wall_corners_nw.png",
		"iso_wall_corners_ne.png"
	}
}

leveleditor_obstacle_category {
	name = "FURNITURE",
	obstacles = {
		"iso_lamp_e.png",
		"iso_lamp_n.png",
		"iso_lamp_s.png",
		"iso_lamp_w.png",
		"iso_urinal_w.png",
		"iso_urinal_s.png",
		"iso_toilet_white_w.png",
		"iso_toilet_white_n.png",
		"iso_toilet_white_e.png",
		"iso_toilet_white_s.png",
		"iso_toilet_beige_w.png",
		"iso_toilet_beige_n.png",
		"iso_toilet_beige_e.png",
		"iso_toilet_beige_s.png",
		"iso_chair_brown_w.png",
		"iso_chair_brown_n.png",
		"iso_chair_brown_e.png",
		"iso_chair_brown_s.png",
		"iso_workdesk_w.png",
		"iso_workdesk_n.png",
		"iso_workdesk_e.png",
		"iso_workdesk_s.png",
		"iso_chair_white_w.png",
		"iso_chair_white_n.png",
		"iso_chair_white_s.png",
		"iso_chair_white_e.png",
		"iso_deskchair_w.png",
		"iso_deskchair_n.png",
		"iso_deskchair_e.png",
		"iso_bed_white_w.png",
		"iso_bed_white_n.png",
		"iso_bed_white_e.png",
		"iso_bed_white_s.png",
		"iso_bench_white_w.png",
		"iso_bench_white_s.png",
		"iso_bench_white_n.png",
		"iso_bench_white_e.png",
		"iso_bathtub_w.png",
		"iso_bathtub_n.png",
		"iso_bathtub_e.png",
		"iso_bathtub_s.png",
		"iso_tub_ns.png",
		"iso_tub_we.png",
		"iso_basin_n.png",
		"iso_basin_e.png",
		"iso_basin_s.png",
		"iso_basin_w.png",
		"iso_sofa_white_e.png",
		"iso_sofa_white_s.png",
		"iso_sofa_white_n.png",
		"iso_sofa_white_w.png",
		"iso_table_elliptic_yellow_ns.png",
		"iso_table_elliptic_yellow_ew.png",
		"iso_table_glass_ns.png",
		"iso_table_glass_we.png",
		"iso_shop_counter_s.png",
		"iso_shop_counter_w.png",
		"iso_shelf_s.png",
		"iso_shelf_e.png",
		"iso_shelf_n.png",
		"iso_shelf_w.png",
		"iso_library_counter_we.png",
		"iso_library_counter_ns.png",
		"iso_chairs_ball_s.png",
		"iso_chairs_ball_w.png",
		"iso_chairs_ball_n.png",
		"iso_chairs_ball_e.png",
		"iso_sofa_red_s.png",
		"iso_sofa_red_w.png",
		"iso_sofa_red_n.png",
		"iso_sofa_red_e.png",
		"iso_bench_red_w.png",
		"iso_bench_red_n.png",
		"iso_bench_red_e.png",
		"iso_bench_red_s.png",
		"iso_stool_brown_w.png",
		"iso_stool_brown_n.png",
		"iso_stool_brown_e.png",
		"iso_stool_brown_s.png",
		"iso_stool_plant_brown_w.png",
		"iso_stool_plant_brown_n.png",
		"iso_stool_plant_brown_e.png",
		"iso_stool_plant_brown_s.png",
		"iso_conference_table_nw.png",
		"iso_conference_table_ne.png",
		"iso_conference_table_es.png",
		"iso_conference_table_ws.png",
		"iso_projectionscreen_s.png",
		"iso_projectionscreen_w.png",
		"iso_projectionscreen_n.png",
		"iso_projectionscreen_e.png",
		"iso_sleepingcapsule_n.png",
		"iso_sleepingcapsule_w.png",
		"iso_sleepingcapsule_s.png",
		"iso_sleepingcapsule_e.png",
		"iso_sleepingcapsule_double_n.png",
		"iso_sleepingcapsule_double_e.png",
		"iso_sleepingcapsule_double_s.png",
		"iso_sleepingcapsule_double_w.png",
		"iso_bookshelf_long_w.png",
		"iso_bookshelf_long_s.png",
		"iso_bookshelf_long_e.png",
		"iso_bookshelf_long_n.png",
		"iso_bookshelf_s.png",
		"iso_bookshelf_e.png",
		"iso_bookshelf_w.png",
		"iso_bookshelf_n.png",
		"iso_barshelf_middle_we.png",
		"iso_barshelf_middle_ns.png",
		"iso_barshelf_left_ns.png",
		"iso_barshelf_left_we.png",
		"iso_barshelf_right_we.png",
		"iso_barshelf_left_ew.png",
		"iso_barshelf_rightouter_ew.png",
		"iso_barshelf_rightouter_we.png",
		"iso_barshelf_rightouter_ns.png",
		"iso_barshelf_leftouter_we.png",
		"iso_counter_small_w.png",
		"iso_counter_small_n.png",
		"iso_counter_small_e.png",
		"iso_counter_small_s.png",
		"iso_counter_small_curve_nw.png",
		"iso_counter_small_curve_ne.png",
		"iso_counter_small_curve_es.png",
		"iso_counter_small_curve_ws.png",
		"iso_counter_small_edge_ws.png",
		"iso_counter_small_edge_nw.png",
		"iso_counter_small_edge_ne.png",
		"iso_counter_small_edge_es.png",
		"iso_table_round_yellow.png",
		"iso_restaurant_counter_w.png",
		"iso_restaurant_counter_n.png",
		"iso_bar_counter_w.png",
		"iso_bar_counter_s.png",
		"iso_pillar_high.png",
		"iso_pillar_short.png",
		"iso_curtain_ns.png",
		"iso_curtain_we.png"
	}
}

leveleditor_obstacle_category {
	name = "MACHINERY",
	obstacles = {
		"iso_raylamp_left.png",
		"iso_raylamp_down.png",
		"iso_raylamp_up.png",
		"iso_raylamp_right.png",
		"iso_purplecloud_3.png",
		"iso_teleport_1.png",
		"iso_droidnest_green_1.png",
		"iso_droidnest_red_1.png",
		"iso_droidnest_blue_1.png",
		"iso_droidnest_yellow_1.png",
		"iso_autogun_on_w.png",
		"iso_autogun_on_n.png",
		"iso_autogun_on_e.png",
		"iso_autogun_on_s.png",
		"iso_autogun_w.png",
		"iso_autogun_n.png",
		"iso_autogun_e.png",
		"iso_autogun_s.png",
		"iso_pot.png",
		"iso_terminal_s.png",
		"iso_terminal_e.png",
		"iso_terminal_n.png",
		"iso_terminal_w.png",
		"iso_terminal_secure_e_01.png",
		"iso_terminal_secure_s_01.png",
		"iso_terminal_secure_w_01.png",
		"iso_terminal_secure_n_01.png",
		"iso_wallterminal_n.png",
		"iso_wallterminal_w.png",
		"iso_wallterminal_s.png",
		"iso_wallterminal_e.png",
		"iso_computerpillar_e.png",
		"iso_computerpillar_n.png",
		"iso_computerpillar_w.png",
		"iso_computerpillar_s.png",
		"iso_cinematograph_n.png",
		"iso_cinematograph_e.png",
		"iso_cinematograph_s.png",
		"iso_cinematograph_w.png",
		"iso_sign_questionmark.png",
		"iso_sign_questionmark_anim_dark.png",
		"iso_sign_exclamationmark.png",
		"iso_sign_exclamationmark_anim_dark.png",
		"iso_sign_lessthenmark.png",
		"iso_sign_lessthenmark_anim_dark.png",
		"iso_trapdoor_e.png",
		"iso_trapdoor_s.png",
		"iso_trapdoor_n.png",
		"iso_trapdoor_w.png",
		"iso_trapdoor_closed_e.png",
		"iso_trapdoor_closed_s.png",
		"iso_trapdoor_closed_n.png",
		"iso_trapdoor_closed_w.png",
		"iso_ladderring_w.png",
		"iso_ladderring_n.png",
		"iso_ladder_w.png",
		"iso_ladder_n.png",
		"iso_ladder_short_n.png",
		"iso_ladder_short_w.png",
		"iso_solarpanel_pillar.png",
		"iso_solarpanel.png",
		"iso_conveyor_ns.png",
		"iso_conveyor_we.png",
		"iso_ramp_w.png",
		"iso_ramp_s.png",
		"iso_ramp_e.png",
		"iso_ramp_n.png",
		"iso_tesla_w.png",
		"iso_tesla_n.png",
		"iso_tesla_e.png",
		"iso_tesla_s.png",
		"iso_roboarm_1_w.png",
		"iso_roboarm_1_n.png",
		"iso_roboarm_1_e.png",
		"iso_roboarm_1_s.png",
		"iso_roboarm_2_w.png",
		"iso_roboarm_2_n.png",
		"iso_roboarm_2_e.png",
		"iso_roboarm_2_s.png",
		"iso_freighter_railway_ns.png",
		"iso_freighter_railway_we.png",
		"iso_freighter_railway_end_s.png",
		"iso_freighter_railway_end_e.png",
		"iso_freighter_railway_end_n.png",
		"iso_freighter_railway_end_w.png",
		"iso_turbines_n.png",
		"iso_turbines_w.png",
		"iso_turbines_s.png",
		"iso_turbines_e.png",
		"iso_reactor_w.png",
		"iso_reactor_s.png",
		"iso_reactor_e.png",
		"iso_reactor_n.png",
		"iso_security_gate_opened_w.png",
		"iso_security_gate_opened_n.png",
		"iso_security_gate_closed_w.png",
		"iso_security_gate_closed_n.png",
		"iso_security_gate_opened_e.png",
		"iso_security_gate_opened_s.png",
		"iso_security_gate_closed_e.png",
		"iso_security_gate_closed_s.png",
		"iso_vendingmachine_blue_w.png",
		"iso_vendingmachine_blue_s.png",
		"iso_vendingmachine_blue_e.png",
		"iso_vendingmachine_blue_n.png",
		"iso_vendingmachine_white_w.png",
		"iso_vendingmachine_white_s.png",
		"iso_vendingmachine_white_e.png",
		"iso_vendingmachine_white_n.png",
		"iso_vendingmachine_red_w.png",
		"iso_vendingmachine_red_s.png",
		"iso_vendingmachine_red_e.png",
		"iso_vendingmachine_red_n.png",
		"iso_transformer.png",
		"iso_transformer_rusty.png",
		"iso_transformer_sparkles.png"
	}
}

leveleditor_obstacle_category {
	name = "CONTAINER",
	obstacles = {
		"iso_chest_grey_closed_n.png",
		"iso_chest_grey_opened_n.png",
		"iso_chest_grey_closed_w.png",
		"iso_chest_grey_opened_w.png",
		"iso_chest_greyrusty_closed_e.png",
		"iso_chest_greyrusty_opened_e.png",
		"iso_chest_greyrusty_closed_w.png",
		"iso_chest_greyrusty_opened_w.png",
		"iso_chest_greyrusty_closed_n.png",
		"iso_chest_greyrusty_opened_n.png",
		"iso_chest_greyrusty_closed_s.png",
		"iso_chest_greyrusty_opened_s.png",
		"iso_barrel.png",
		"iso_barrel_rusty.png",
		"iso_barrel_radioactive.png",
		"iso_crate_ns.png",
		"iso_crate_we.png",
		"iso_crate_ns_megasys.png",
		"iso_weapon_crate.png",
		"iso_bookshelf_long_lootable_e.png",
		"iso_bookshelf_long_lootable_s.png",
		"iso_bookshelf_long_lootable_w.png",
		"iso_bookshelf_long_lootable_n.png",
		"iso_bookshelf_lootable_e.png",
		"iso_bookshelf_lootable_s.png",
		"iso_bookshelf_lootable_w.png",
		"iso_bookshelf_lootable_n.png",
		"iso_statue_883_e.png",
		"iso_statue_883_n.png",
		"iso_statue_883_s.png",
		"iso_statue_883_w.png"
	}
}

leveleditor_obstacle_category {
	name = "NATURE",
	obstacles = {
		"iso_tree_1.png",
		"iso_tree_2.png",
		"iso_tree_3.png",
		"iso_tree_big.png",
		"iso_tree_stump.png",
		"iso_shroom_white_1.png",
		"iso_shroom_white_2.png",
		"iso_shroom_blue_1.png",
		"iso_shroom_blue_2.png",
		"iso_shroom_blue_3.png",
		"iso_rock_small.png",
		"iso_rock_big.png",
		"iso_rock_pillar.png",
		"iso_crystal_pillar_1.png",
		"iso_crystal_stump_1.png",
		"iso_crystal_stump_2.png",
		"iso_crystal_stump_3.png",
		"iso_crystal_pillar_2.png",
		"iso_crystal_pillar_3.png"
	}
}

leveleditor_obstacle_category {
	name = "OTHER",
	obstacles = {
		"iso_electronicscrap_1.png",
		"iso_electronicscrap_2.png",
		"iso_electronicscrap_3.png",
		"iso_electronicscrap_4.png",
		"iso_electronicscrap_5.png",
		"iso_electronicscrap_6.png",
		"iso_electronicscrap_7.png",
		"iso_electronicscrap_8.png",
		"iso_body_human.png",
		"iso_wrecked_car_w.png",
		"iso_wrecked_car_s.png",
		"iso_wrecked_car_e.png",
		"iso_wrecked_car_n.png",
		"iso_crushed_476.png",
		"floor_tiles/iso_collapsingfloor_visible.png",
                "iso_stratopod_landed_s_0001.png"
	}
}
