---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
background = "credits.jpg",
song = "TheBeginning.ogg",
text = [[
            HOGYAN MŰKÖDJ KÖZRE

A FreedroidRPG teljesen szabad szoftver és szabad grafika.
Kizárólag önkéntesek fejlesztik, a szabadidejükben.

A FreedroidRPG ezekre a közreműködésekre támaszkodik, hogy jobb játék legyen.
Ha szeretnél valamivel közreműködni, de nem vagy benne biztos, hogy mit tegyél, itt egy lista:

TESZTELÉS ÉS HIBAJELENTÉS:

Olyan emberekre van szükségünk, akik kipróbálják a játékot, és jelentenek mindent, ami nem működik vagy nem stabil. Ez apró dolgokat is jelent, mint az elírások és hasonlók. A tesztelés feladata a FreedroidRPG méretével együtt nő. Szükségünk van a segítségre.
Nyugodtan küldj foltokat!

PÁLYAKÉPKÉSZÍTÉS:

Olyan embereket keresünk, akik pályákat készítenek nekünk. Beépített pályaszerkesztő van a játékban. Próbáld ki, és ha valami érdekeset csinálsz, akkor biztosan megkeresünk.

DOKUMENTÁCIÓ:

Jelenleg alig van dokumentációnk. Végfelhasználói dokumentációra van szükségünk a játékhoz és a pályaszerkesztőhöz, valamint fejlesztőket célzó dokumentációra. Jó íráskészség szükséges.

HANGHATÁSOK:

Hasznát vennénk a jó hanghatásoknak. Ha egy jó célban akarsz közreműködni, akkor nem fogunk visszautasítani. :)

KAPCSOLAT:

Ha közre akarsz működni valamiben, vagy visszajelzést adnál a játékhoz, akkor könnyen kapcsolatba léphetsz a fejlesztőkkel. Csak küldj egy e-mailt a következő címre:
freedroid-discussion@lists.sourceforge.net

Or, if you prefer, you might want to pop into our IRC channel (#freedroid on irc.libera.chat). Everyone's invited. Bring your friends!

Köszönjük,

            A FreedroidRPG fejlesztőcsapata.
]]
}
