---------------------------------------------------------------------
--
--  Copyright (c) 2002, 2003 Johannes Prix
--
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
background = "credits.jpg",
song = "HellFortressTwo.ogg",
text = [[
    ¿Te diviertes?
  No lo soy.

The bots seem very upset about something.
  I suppose they are angry at you.
    At least they stopped looking for me.
      Quite a ?relief?

    I'm sure you are dying to talk to me.
  I'll think of something.
For now you can only listen.
  You will have to live with it for now.

    Our leader got his brain fried.
      This means I'm taking over.
        I'm quite fed up.
      I hate this world.
    We are getting out of here.

  I have found Qwerty, but this means nothing.
His core temperature is above the freezing point.
  In other words, he is dead.
    I won't miss him.

I cannot find Arensito.
  I hope she is fine.
    I'm ?worried? about her.
    We don't really need Qwerty.
  But we need Arensito.
    I'll keep looking for her.

    There is an AI in your region.
  "Singularity" it calls itself.
Or something like that.
  I cannot understand what it wants.
    I'll keep you posted.

  Oh, and by the way...
The bots are killing everyone in that small town nearby.
  Really, quite a sight. They are burning everything.
    The Red Guard citadel is still holding.
      For now.
    You might want to hide while they wreck the place.
  In a few hours it should be safe to go there again.

  I think that covers everything.
    I'm going to start preparing for departure now.
  So should you.
We need to find Arensito.
  She will get us out from here.

            Dvorak, Primera AI.



 To be continued...



A word from the FreedroidRPG development team:

We hope that you liked our game.

If you want to add something to the game, that would be wonderful. There are plenty of opportunities to do so. We especially need more content, i.e.:

* additional level design beautification
* new level ideas
* anything else you can come up with

See also the 'Contribute' section.

The freedroid development team.


Press Fire to continue
]]
}
