---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
background = "credits.jpg",
song = "TheBeginning.ogg",
text = [[
            HUR MAN BIDRAR

FreedroidRPG är helt och hållet fri programvara och fria illustrationer.
Det utvecklas av volontärer på deras fritid.

FreedroidRPG är beroende av sådana bidrag för att bli ett bättre spel.
Om du vill bidra med något, men inte är säker på vad, så följer här en lista på saker:

TESTANDE OCH BUGGRAPPORTER:

Vi behöver folk som testar spelet och rapporterar saker som inte fungerar som de ska eller verkar instabila. Det innefattar småsaker som stavningsfel och liknande. Arbetet att testa växer i och med att FreedroidRPG växer. Vi behöver din hjälp.
Tveka inte att skicka in en patch!

KARTSKAPANDE:

Vi söker efter personer som vill göra kartor åt oss. Det finns en inbyggd karteditor. Testa den, och om du skapat något intressant, se till att kontakta oss.

DOKUMENTATION:

Vi har för nuvarande brist på dokumentation. Vi skulle behöva en användarmanual till spelet och till kartredigeraren, såväl som dokumentation riktad till utvecklare. Bra skrivkunskaper krävs.

LJUDEFFEKTER:

Vi skulle gott behöva ljudeffekter. Om du vill bidra med några till ett gott ändamål kommer vi inte tacka nej. :)

KONTAKT:

Om du vill bidra med något eller ge feedback om spelet, kan du enkelt få kontakt med utvecklarna. Skicka bara ett brev till den här e-postadressen:
freedroid-discussion@lists.sourceforge.net

Eller, om du föredrar, kan du hoppa in i vår IRC-kanal (#freedroid på irc.libera.chat). Alla är välkommna. Ta med dig dina vänner!

Tack,

            Utvecklarna bakom FreedroidRPG.
]]
}
