---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
background = "credits.jpg",
song = "TheBeginning.ogg",
text = [[
            JAK PŘISPĚT

FreedroidRPG je zcela svobodný software a svobodné dílo.
Je vyvíjen výhradně dobrovolníky v jejich volném čase.

Aby se FreedroidRPG mohl neustále zlepšovat, závisí na těchto dobrovolných příspěvcích.
Pokud byste chtěli něčím přispět, ale nejste si zcela jisti čím nebo jak, zde je seznam možností:

TESTOVÁNÍ A REPORTOVÁNÍ CHYB:

Potřebujeme lidi, kteří hru vyzkouší a nahlásí cokoli, co nefunguje správně nebo se nezdá být stabilní. To zahrnuje drobné věci jako je kontrola překlepů, chyb v textu a podobně. Úloha testování roste s velikostí hry FreedroidRPG. Potřebujeme vaši pomoc.
Neváhejte a posílejte nám návrhy na opravy (patche)!

TVORBA MAP:

Hledáme lidi, kteří by pro nás dělali mapy. K dispozici je editor map vestavěný ve hře. Zkuste ho a když uděláte něco zajímavého, ujistěte se, že se vaše práce dostane zpět k nám.

DOKUMENTACE:

V současné době se potýkáme s nedostatkem dokumentace. Potřebovali bychom uživatelskou dokumentaci vztahující se ke hře a jejímu editoru úrovní stejně tak, jako dokumentaci cílenou na vývojáře. Předpokladem je schopnost dobrého psaní.

ZVUKOVÉ EFEKTY:

Z cela určitě bychom mohli použít zvukové efekty. Chcete-li nějakým přispět, rozhodně vás neodmítneme. :)

KONTAKT:

Pokud byste rádi něčím přispěli nebo poskytli zpětnou vazbu ohledně hry, můžete se jednoduše spojit s vývojáři. Stačí poslat e-mail na následující adresu:
freedroid-discussion@lists.sourceforge.net

Nebo se můžete zastavit na našem IRC kanálu (#freedroid na irc.libera.chat).  Všichni jsou vítáni. Přiveďte i své přátele!

Díky,

            Tým vývojářů FreedroidRPG.
]]
}
