---------------------------------------------------------------------
--
--  Copyright (c) 2002, 2003 Johannes Prix
--
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
background = "credits.jpg",
song = "HellFortressTwo.ogg",
text = [[
    Se divertindo?
  Eu não.

Os robôs parecem perturbados com alguma coisa.
  Suponho que estejam com raiva de você.
    Mas pelo menos pararam de me procurar.
      Aliviador? Não?

    Imagino que você está querendo falar comigo.
  Vou pensar em alguma coisa.
Por enquanto você só pode me ouvir.
  Você vai ter de viver com isso por enquanto.

    Nosso líder teve ser cérebro frito.
      Isso significa que eu estou assumindo.
        Estou farto.
      Odeio este mundo.
    Estamos saindo daqui.

  Eu encontrei Qwerty, mas isso não significa nada.
A sua temperatura interna está acima do congelamento.
  Em outras palavras, ele está morto.
    Não sentirei sua falta.

Não consigo encontrar Arensito.
  Espero que ela esteja bem.
    Eu estou ?preocupado? com ela.
    Não precisamos realmente do Qwerty.
  Mas precisamos da Arensito.
    Continuarei procurando por ela.

    Tem um IA na sua região.
  Chama a si mesmo de "Singularidade".
Ou algo assim.
  Eu não consigo entender o que ele quer.
    Lhe manterei informado.

  Oh, e por falar nisso...
Robôs estão matando a todos daquela cidadezinha aí perto.
  Realmente, que visão... Eles estão queimando tudo.
    A cidadela da Guarda Vermelha ainda está aguentando.
      Por enquanto.
    Talvez você queira se esconder enquanto é destruído
  Em algumas horas deverá ser seguro voltar lá novamente.

  Acho que isso cobre tudo.
    Vou começar os preparativos para a partida agora.
  Você também deveria.
Precisamos encontrar Arensito.
  Ela vai nos tirar daqui.

            Dvorak, Primeiro IA.



Continua...



Uma palavra de equipe de desenvolvimento de FreedroidRPG:

Esperamos que você tenha gostado do nosso jogo.

Se você quiser adicionar algo ao jogo, isso seria maravilhoso. Há várias oportunidade para fazê-lo. Precisamos especialmente de mais conteúdo, por exemplo:

* Embelezamento adicional ao design de mapas
* Novas ideias de níveis
* O que quer você consiga imaginar

Veja também a seção "Contribuir".

A equipe de desenvolvimento do FreedroidRPG.


Clique para continuar
]]
}
