---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
background = "credits.jpg",
song = "TheBeginning.ogg",
text = [[
            COMMENT CONTRIBUER

FreedroidRPG est entièrement libre, le logiciel et les illustrations.
Il est exclusivement développé par des bénévoles sur leur temps libre.

L'amélioration de FreedroidRPG dépend de ces contributions.
Si vous désirez contribuer, mais n'êtes pas certain de savoir comment, voici une liste de choses à faire :

TEST ET RAPPORT DE BUG :

Nous avons besoin de personnes pour tester le jeu et rapporter tout ce qui ne fonctionne pas correctement ou qui semble instable. Cela inclut des choses mineures telles que des erreurs d'orthographe ou autre. Cette tâche augmente avec la taille de FreedroidRPG. Nous avons besoin de votre aide. 
N'hésitez pas à envoyer des patchs.

CRÉATION DE CARTES :

Nous recherchons des personnes pour créer les cartes. Un éditeur de carte est intégré au jeu. Essayez-le, et si vous créez quelque chose d'intéressant, pensez à nous l'envoyer.

DOCUMENTATION :

Nous manquons actuellement de documentation. Nous aurions besoin d'une documentation décrivant le jeu et son éditeur de niveau, aussi bien destinée à l'utilisateur final qu'au développeur. Un bon niveau d'écriture est requis.

BRUITAGES :

Nous pourrions certainement utiliser quelques effets sonores. Si vous voulez contribuer à une bonne cause, nous ne dirions pas non. :)

CONTACTS :

Si vous désirez contribuer ou donner votre avis sur le jeu, vous pouvez facilement contacter les développeurs. Envoyez simplement un mail à l'adresse suivante :
freedroid-discussion@lists.sourceforge.net

Ou, si vous préférez, vous pouvez nous rejoindre sur notre salon de discussion IRC (#freedroid sur irc.libera.chat). Tout le monde est invité. Venez avec vos amis !

Merci.

            L'équipe de développement de FreedroidRPG.
]]
}
