---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
background = "credits.jpg",
song = "TheBeginning.ogg",
text = [[
            КАК ПОМОЧЬ

FreedroidRPG — полностью свободное программное обеспечение и произведение искусства.
Разрабатывается исключительно добровольцами в их свободное время.

FreedroidRPG зависит от такого вклада, чтобы стать лучшей игрой.
Если вы хотите помочь чем-нибудь, но не знаете как и чем, вот список задач:

ТЕСТИРОВАНИЕ И СООБЩЕНИЯ ОБ ОШИБКАХ:

Нам нужны люди, которые попробуют игру и сообщат обо всё, что работает неправильно или выглядит нестабильным. Сюда входят и мелкие вещи, вроде исправления опечаток и т. п. Задача тестирования растёт вместе с ростом FreedroidRPG. Нам нужна ваша помощь.
Не стесняйтесь отправлять патчи!

СОЗДАНИЕ КАРТ:

Мы ищем людей, которые делали бы карты для нас. В игру встроен редактор карт, попробуйте его и, если создадите что-нибудь интересное, не забудьте прислать нам.

ДОКУМЕНТАЦИЯ:

Сейчас мы испытываем недостаток в документации. Нам нужна документация для конечного пользователя, касающаяся игры и её редактора уровней, а также документация, ориентированная на разработчиков. Требуется хороший навык письма.

ЗВУКОВЫЕ ЭФФЕКТЫ:

Конечно, мы могли бы использовать какие-нибудь звуковые эффекты. Если вы хотите помочь в этом добром деле, мы не будем вас останавливать. :)

СВЯЗЬ:

Если вы захотите помочь или написать отзыв об игре, вы можете легко связаться с разработчиками. Просто отправьте электронное письмо на адрес:
freedroid-discussion@lists.sourceforge.net

Или, смотря по предпочтениям, можете заглянуть в наш IRC-канал (#freedroid on irc.libera.chat). Приглашаем всех. И друзей приводите!

Спасибо,

            команда разработчиков FreedroidRPG
]]
}
