---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "TheBeginning.ogg",
text = [[
Trying to hack someone, eh?
Don't remember how to do it?
Stupid. Don't fry your brain and then try hacking.
Here is a crash course to refresh your memory.

First, don't try to hack if you are about to die.
If you fail, you will get a nice electric shock.
It won't kill you unless you already are really hurt, but it will hurt.
A lot.

There are two phases of hacking.
First choose the circuit board you consider to be the best.
One is yellow and the other is purple.
Just press left or right on your keyboard to choose.
You have about 10 seconds before the bot notices you.
Pick the board which you think gives you an advantage.

The second phase is making connections to the logic cores.
In case you are wondering, these are the things in the center.

Because bots are buggy, some cores will be on your side.
You can make only a few attacks, so make them count.
Choose the wire you want to use to attack the cores with.
Pressing up and down on your keyboard should work.
You can also use the mouse wheel if you have one.
When you have made up your mind, press the blank bar.
Whatever is on the other side of the wire will become yours.
Of course the bot won't just sit there like an onion.
It will try to regain control and it will make connections too.

After a short while everything will be over.
If you control the most cores at this moment, the bot belongs to you.
If not, you get a free electrocution, MegaSys style.

The wiring inside the bots is quite crazy at times.
You will have to learn the details by yourself.
I'm not going to risk my safety for your convenience.
Too many bots to keep transmitting for too long.

Oh, and a request.
Next time you decide to stir fry your brain...
Just take the manuals into stasis sleep with you.
I might not be there to save you next time.

            Dvorak, First AI.
]]
}
