---------------------------------------------------------------------
--
--  Copyright (c) 2002, 2003 Johannes Prix
--
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
background = "credits.jpg",
song = "HellFortressTwo.ogg",
voice_acting = "EndOfAct.ogg",
preroll_text = 2,
postroll_text = 5,
text = [[
    Bavíš se?
  Já ne.

Roboti se zdají být kvůli něčemu velmi naštvaní.
Předpokládám, že jsou rozhněvaní na tebe.
Alespoň mě přestali hledat.
Docela? ...úleva?

V tvé oblasti je umělá inteligence.
Říká si "Singularita".
Nebo tak nějak.
Nechápu, co chce.
Budu tě informovat.

Oh a mimochodem...
Pořád tu na tebe čekám.
Od chvíle, kdy ses probudil, jsem se nehnul ani o píď.
Teď, kdy je tvé milované město v bezpečí...
...Nebylo by už na čase zachránit i mě?

            Dvořák, První umělá inteligence.



=== KONEC 1. AKTU ===

]]
}
