---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "HellFortressTwo.ogg",
voice_acting = "GameLost.ogg",
preroll_text = 3,
postroll_text = 3,
text = [[
            Вы проиграли

Пожалуйста, попытайтесь снова, а затем обязательно купите товар наших спонсоров:

Д-р Как. Невероятно удобная технология!

Кан4дские ф4рм4цевты. Невероятный прорыв травяной 3ащNты! 100% удовлетворение гарантир0вано!!!

Крионик Солюшнс. Соверши быстрое путешествие в будущее с Крионик Солюшнс!

Баллистика будущего. За пределами баллистики. Баллистика будущего.

МегаСистемс. Чего вы не хотите делать сегодня?

Вывоз мусора Мастернака. Мы СОКРУШИМ ваш МУСОР.

Компания Николсона. Безопасность с возмездием.

Красное Солнце. Ночь закончилась: вкуси рассвет!



Пожалуйста, попробуйте еще раз. Кликните чтобы продолжить.
]]
}
