---------------------------------------------------------------------
--
--  Copyright (c) 2002, 2003 Johannes Prix
--
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
background = "credits.jpg",
song = "HellFortressTwo.ogg",
text = [[
    Hast du Spaß gehabt?
  Ich nicht.

Die Robos scheinen sehr verärgert zu sein.
  Ich glaube, sie regen sich über dich auf.
    Wenigstens sehen sie mich nicht mehr an.
      Was für eine ?Erleichterung?

    Ich bin sicher, dass du dringend mit mir reden willst.
  Ich denke darüber nach.
Im Moment kannst du nur zuhören.
  Damit wirst du leben müssen.

    Das Hirn unseres Anführers wurde eingefroren.
      Das heißt, ich übernehme jetzt.
        Mir reicht es langsam.
      Ich hasse diese Welt.
    Wir müssen von hier weg.

  Ich habe Qwerty gefunden, doch das hat nichts zu bedeuten.
Seine Kerntemperatur liegt über dem Gefrierpunkt.
  Mit anderen Worten, er ist tot.
    Ich werde ihn nicht vermissen.

Ich kann Arensito nicht finden.
  Ich hoffe ihr geht es gut.
    Ich bin ?besorgt? über sie.
    Wir brauchen Qwerty nicht wirklich.
  Aber wir brauchen Arensito.
    Ich werde weiterhin nach ihr suchen.

    Es befindet sich eine KI in deiner Umgebung.
  Sie nennt sich selbst "Singularität".
Oder so.
  Ich kann nicht verstehen, was sie will.
    Ich werde dich weiterhin informieren.

  Oh, und nebenbei…
Die Robos töten jeden in der kleinen Stadt dort drüben.
  Wirklich, was für ein Anblick. Sie brennen alles nieder.
    Die Zitadelle der Roten Garde hält weiterhin Stand.
      Bis jetzt.
    Vielleicht solltest du dich verstecken, während sie alles in Schutt und Asche verwandeln.
  In ein paar Stunden sollte hier alles wieder sicher sein.

  Ich denke, das schließt alles hier ein.
    Ich werde mich jetzt zur Abreise bereit machen.
  Das solltest du.
Wir müssen Arensito finden.
  Sie wird uns hier raus holen.

            Dvorak, die erste KI.



 Fortsetzung folgt…



Ein paar Worte vom FreedroidRPG-Entwicklungsteam:

Wir hoffen, dass euch unser Spiel gefallen hat.

Wenn ihr etwas dem Spiel hinzufügen wollt, wäre das wundervoll. Es gibt eine Menge Gelegenheiten, die ihr ergreifen könnt. Wir benötigen mehr Inhalte, insbesondere:

* mehr Designs zum Aufhübschen von Karten
* neue Levelideen
* und andere Dinge, die euch sonst so einfallen

Schaut auch im Abschnitt "Mitwirkung" rein.

Das Freedroid-Entwicklungsteam.


Taste drücken zum Fortfahren…
]]
}
