---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "Bleostrada.ogg",
voice_acting = "StartOfGame.ogg",
preroll_text = 3,
postroll_text = 3,
text = [[
Jakýž toť nádherný den.
Ano, jsem zase sarkastický.
Celá planeta je v plamenech.
Tisíce lidí jsou po smrti.
Qwerty a Arensito nereagují.

Ah ano, málem jsem zapomněl.
Ti prokletí roboti mě každou chvíli najdou.
Nejsem z toho moc nadšený. Nejsem vůbec nadšený.
Evidentně budu muset předstírat, že jsem jen kus pěkný skály. Už zase.
Nemyslíš si, že by bylo na čase se probudit?
Vstávat. Okamžitě sem. Zachraň mi zadek.
Prosím.

            Dvořák, První umělá inteligence.
]]
}
