---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "TheBeginning.ogg",
text = [[
Tentando hackear alguém, é?
Não se lembra como fazê-lo?
Estúpido. Não frite seu cérebro e, então, tente hackear.
Aqui vai um curso intensivo pra refrescar a sua memória.

Primeiro, não tente hackear se estiver prestes a morrer.
Se você falhar, vai receber um belo choque elétrico.
Não te matará a não ser que você já esteja bastante ferido, mas vai doer.
Bastante.

Existem duas fases ao se hackear.
Primeiro escolha a placa de circuitos que você considerar a melhor.
Uma é amarela e a outra é roxa.
Apenas aperte esquerda ou direita no seu teclado pra escolher.
Você tem uns 10 segundos antes que o robô te note.
Escolha a placa que você achar que lhe dará uma vantagem.

A segunda fase é realizar conexões aos núcleos lógicos.
Se estiver se perguntando, são essas coisas no centro.

Porque robôs são defeituosos, alguns desses núcleos começarão a seu favor.
Você só pode fazer alguns ataques, então faça-os valer a pena.
Escolha o fio que deseja usar para enviar a carga e se conectar.
Apertar as teclas de cima e baixo em seu teclado deve funcionar.
Você também pode usar a rodinha do mouse se tiver uma.
Quando você se decidir, aperta a barra de espaço.
O que estiver do outro lado do fio se tornará seu.
É claro que o robô não ficará lá parado como uma cebola.
Ele tentará recuperar o controle e fará algumas conexões também.

Após um breve período de tempo tudo estará acabado.
Se você controlar a maioria dos núcleos nesse momento, o robô te pertence.
Se não, você recebe uma eletrocussão grátis, ao estilo da MegaSys.

A fiação dentro desses robôs às vezes é uma doideira.
Você terá de aprender os detalhes por conta própria.
Eu não vou arriscar a minha segurança pela sua conveniência.
Há robôs demais pra ficar transmitindo por tanto tempo.

Ah, e um pedido.
Na próxima vez que resolver fritar o seu cérebro...
Apenas leve os manuais antes de entrar em estase criogênica.
Eu posso não estar lá para te salvar na próxima vez.

            Dvorak, Primeiro IA.
]]
}
