---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "TheBeginning.ogg",
text = [[
Wolltest einen Bot hacken?
Aber weißt nicht mehr wie?
Dummkopf. Schalt dein Hirn wieder ein und versuch's nochmal.
Hier ein Schnellkurs zur Erinnerung.

Erstens, hacke nicht, wenn du dem Tod nahe bist.
Scheiterst du, bekommst du einen Elektroschock.
Er wird dich nicht umbringen, außer du bist SEHR nahe am Abkratzen.
Es kitzelt nur ein bisschen.

Das Hacken ist in 2 Phasen eingeteilt.
Zuerst wählst du die Seite, von der du glaubt, du hättest die besten Chancen.
Die eine Seite ist gelb, die andere violett.
Drücke Links oder Rechts auf der Tastatur, um dich für eine Seite zu entscheiden.
Du hast nur 10 Sekunden, bis der Bot dich bemerkt.
Wie gesagt, wähle die Seite, die dir mehr Vorteile gibt.

In der Zweiten Phase musst du Verbindungen zu den logischen Kernen aufbauen.
Falls du dich wunderst, das sind die Dinger in der Mitte.

Weil die Roboter fehlerhaft sind, sind auch ein paar der Kerne auf deiner Seite.
Du hast nur eine begrenzte Anzahl an Zügen, also plane sorgfältig.
Wähle einen Draht, um den Kern anzugreifen.
Drücke Hoch oder Runter auf deiner Tastatur, das sollte funktionieren.
Falls du ein Mausrad hast, kannst du auch das verwenden.
Hast du deine Entscheidung getroffen, drücke die Leertaste.
Was auch immer an der anderen Seite des Drahtes liegt, wird dann dir gehören.
Natürlich ist der Bot nicht so dumm wie Brot und tut gar nichts.
Er wird versuchen die Kontrolle wiederzuerlangen.

Doch nach kurzer Zeit wird alles vorbei sein.
Solltest du zu diesem Zeitpunkt die meisten Kerne besitzen, gehört der Robo dir.
Falls nicht, koste den Gratis-Schock im MegaSys-Style.

Die Verkabelung der Blecheimer ist manchmal ziemlich verrückt.
Den Rest wirst du selbst lernen müssen.
Ich werde nicht meine Sicherheit für deine Bequemlichkeit riskieren.
Zu viele Robos um eine lange Übertragung aufrechtzuerhalten.

Oh, und eine Bitte noch.
Schalte dein Hirn nicht wieder ab…
Nimm einfach die Anleitungen mit in deine Stasis.
Beim nächsten Mal werde ich nicht bei dir sein, um dich zu retten.

            Dvorak, die erste KI.
]]
}
