---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "HellFortressTwo.ogg",
voice_acting = "GameLost.ogg",
preroll_text = 3,
postroll_text = 3,
text = [[
            Partie Perdue

Réessaie encore, et en le faisant, n'oublie pas de passer commande auprès de nos sponsors :

Dr. How - "Puissante technologie pratique"

Ph4rm4cie Can4dienne - "Extraordinaires r3mèdes phytothérapiqu3s innov4nts ! Satisfaction 100% g4ranti3 !!!"  

Solution Cryonic - "Prenez un aller simple et rapide pour le futur avec Solutions Cryonic !"  

Future Ballistics - "Bien mieux que Ballictics. Future Ballistics, la nouvelle génération." 

MegaSystems - "De quoi n'avez-vous pas envie aujourd'hui ?"

Masternak Tri et Collecte - "Nous CONCASSONS vos DÉTRITUS."

Compagnie Nicholson - "La sécurité avec un poil de vengeance." 

Soleil Rouge - "La nuit est fini : Le goût de l'aube"



Ressayez encore s'il-vous-plaît. Appuyer pour continuer.
]]
}
