---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "HellFortressTwo.ogg",
voice_acting = "GameLost.ogg",
preroll_text = 3,
postroll_text = 3,
text = [[
            Game Lost

Please try again, and when you do, be sure to buy from our sponsors:

Dr. How - "Mighty convenient technology!"

Can4dian ph4rm4cy - "Amazing breakthrough herbal r3medies! 100% satisfaction guarant3ed!!!"

Cryonic Solutions - "Take the fast trip to the future with Cryonic Solutions!"

Future Ballistics - "Beyond ballistics. Future Ballistics."

MegaSystems - "What don't you want to do today?"

Masternak Rubbish Removal - "We CRUSH your RUBBISH."

Nicholson Company - "Security with a vengeance."

Red Sun - "The night is over: taste the dawn!"



Please try again. Click to continue.
]]
}

