---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "HellFortressTwo.ogg",
voice_acting = "GameLost.ogg",
preroll_text = 3,
postroll_text = 3,
text = [[
            Játék elvesztve

Próbáld újra, és amikor ezt teszed, akkor vásárolj a szponzorainktól:

Dr. How – „Rendkívül kényelmes technológia!”

Kan4dai gy0gysz3r – „Elképesztő áttörés a növényi gyógysz3rekben! 100% elégedettség guarantálv4!!!”

Cryonic Solutions – „Utazzon a jövőbe a gyorsabb úton a Cryonic Solutions-zel!”

Future Ballistics – „Több mint ballisztika. Future Ballistics.”

MegaSystems – „Mit szeretnél ma tenni?”

Masternak szemétszállítás – „SZÉTZÚZZUK a SZEMETÉT”

Nicholson vállalat – „Biztonság bosszúval.”

Vörös nap – „Az éjnek vége: kóstold meg a hajnalt!”



Próbáld újra. Kattints a folytatáshoz.
]]
}
