---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
background = "credits.jpg",
song = "TheBeginning.ogg",
text = [[
            WIE MAN MITWIRKEN KANN

FreedroidRPG ist komplett freie Software und freie Kunst.
Es wird exklusiv von seinen Unterstützern in ihrer Freizeit entwickelt.

FreedroidRPG hängt von diesen Mitwirkenden ab, um ein besseres Spiel zu werden.
Wer mitwirken will, aber nicht komplett sicher ist wie, findet in dieser Liste hier ein paar Möglichkeiten:

TESTS UND FEHLERMELDUNG:

Wir brauchen Leute, die das Spiel ausprobieren und alles bemängeln, was nicht richtig zu funktionieren scheint oder nicht zuverlässig genug läuft. Dies schließt auch Kleinigkeiten wie Schreibfehler mit ein. Je größer das Spiel wird, um so umfangreicher werden auch die Tests. Wir benötigen jede Hilfe.
Und wer Verbesserungen in Form von Patches schreibt, soll nicht zögern, sie den Entwicklern zuzuschicken!

KARTENERSTELLUNG:

Wir suchen nach Leuten, die Karten für uns erstellen können. Ein passender Karteneditor ist in diesem Spiel eingebaut. Probiert ihn aus. Wer etwas wirklich interessantes erstellt hat, sollte es uns Entwicklern zusenden.

DOKUMENTATION:

Wir hängen mit der Dokumentation hinterher. Wir brauchen eine Endbenutzer-Dokumentation, die sich auf das Spiel und den Level-Editor bezieht, genauso wie eine Entwickler-Dokumentation. Gute Schreibfähigkeiten werden erwartet.

SOUNDEFFEKTE:

Wir können sicherlich ein paar Soundeffekte gebrauchen. Wir werden nicht nein sagen, wenn jemand etwas aus gutem Grund dazu beitragen kann. :)

KONTAKT:

Wer etwas beitragen kann oder Verbesserungsvorschläge zum Spiel hat, kann einfach mit den Entwicklern in Kontakt treten. Sendet einfach eine E-Mail an folgende Adresse:
freedroid-discussion@lists.sourceforge.net

Wer direkteren Kontakt wünscht, kann auch auf unserem IRC-Kanal (#freedroid on irc.libera.chat) vorbeischauen. Bringt Freunde mit! ACHTUNG: Nur auf Englisch! 

Vielen Dank,

            Das FreedroidRPG-Entwicklungsteam.
]]
}
