---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
background = "credits.jpg",
song = "HellFortressTwo.ogg",
text = [[
            FreedroidRPG 1.0

ПРОГРАММИРОВАНИЕ:

        Сэмюэль Дегранд
        Кристов Франзен
        Скотт Фурри
        Артур Юйе
        Грегори Лозе
        lumidify
        specing
        Стефан Кэнгэс
        Xenux

НАПОЛНЕНИЕ ИГРЫ:

        alex
        Канджаппу Абиджит
        DroidBotAI
        Рафаэль Фонтелли
        can-ned_food
        Скотт Фурри
        Робин Гэриус
        Infrared
        Маттиас Крюгер
        Richard Lightman
        Майлз Маккамон
        Жонатас Л. Ногейра
        pekpek
        Sydney
        wlan2

ГРАФИКА:

        Infrared
        Бастиан Салмела

МУЗЫКА:

        girix8
        pekpek

SFX:

        pekpek

ПЕРЕВОДЫ:

        чешский:
          Ян Тойнар
          Zdenek Chmelar

        немецкий:
          JМ Франц
          Маттиас Крюгер
          lumidify
          Линк Марио

        испанский:
          Педро Арана
          Карлос Даниэль Лэндин Монтэперто
          Luisi Nogueira
          Dani Quiroz
          Луа Марчант Телло
          Valora Valenteno

        французский:
          Себастьян Адам
          Алерион
          Бенджамин Бертран
          Stevens D.
          Сэмюэль Дегранд
          Николя Фаржье
          Бенжамен Ледюк
          Дыон Кханг Нгуен
          syl_
          Xenux

        венгерский:
          Блазс Меско

        итальянский:
          ginoingras
          Michele Marongiu
          Silvia
          Себастиано Песторе
          Emanuele Sorce

        бразильский португальский:
          Анелиз Д. Дж.
          Луис Фелипе Феррейра да Силва
          Рафаэль Фонтелли
          Жонатас Л. Ногейра

        русский:
          algan011
          listores
          Родион
          Роман М. Ягодин

        шведский:
          Александр Форсберг
          Джонатан Найберг

РАЗНОЕ:

        Жульен Пьюдт



            А ТАКЖЕ В ПРЕДЫДУЩИХ ВЕРСИЯХ:

ПРОГРАММИРОВАНИЕ:

        Мария Грация Аластра
        Педро Арана
        Кэтэлин Бадя
        Боб
        Пьер Бурдон
        Брайан Си
        Симон Кастельян
        Майк Фляйшманн
        Янн Хорн
        jcoral
        Джозеф Кусия
        Паулика Матей
        Майлз Маккамон
        Майкл Мендельсон
        Иса-Маттей Моуруджарви
        Ари Мустонен
        Майкл Паркс
        Николас Пепин-Перрулт
        Сэмюэль Питуазе
        Квентин Прэдет
        Иоганнес Прикс
        Райнхард Прикс
        Александр Соловец
        Филипп Титар
        v4hn

НАПОЛНЕНИЕ ИГРЫ:

        Эми Батлер
        Стефан Хазикс
        Джеймс
        Рэймонд Дженнингс
        Себастиан Офферман
        Кертис Пэррэмо
        Никлас Спилл
        Starminn
        Кэрол Светицки
        rudi_s
        Thor
        JK Wood
 
МУЗЫКА:

        Ник "Nario" Хэгман
        Арвид Пицциани
        "The Beginning"
            by 4t thieves
        "Daybreak"
            by realsmokers
        "Bleostrada"
            by stud

РАЗНОЕ:

        MBROLA - преобразование текста в речь
        eSpeak - преобразование текста в речь
        Райан 'simcop2387' Вутис
        Эндрю А. Гилл
        Zombie Ryushu
        Ted Cipicchio
        Доктор
        Эйно Кескитало
        Саймон Ньютон
        Дыон Кханг Нгуен
        Клинт Херрон
        Хайк Данакян
        Иэн Гриффитс
        Дэвид Кремер
        Армин Уинтерер
]]
}
