---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "Bleostrada.ogg",
voice_acting = "StartOfGame.ogg",
preroll_text = 3,
postroll_text = 3,
text = [[
Vilken härlig dag.
Ja, jag är sarkastisk igen.
Hela planeten står i lågor.
Tusentals personer är väldigt döda.
Qwerty och Arensito svarar inte.

Ja, just det, jag glömde nästan.
De förbaskade bottarna håller på hitta mig också.
Jag är inte så glad över det. Inte glad alls.
Jag antar att jag måste låtsas att jag är en liten sten, igen.
Tycker du inte att det är dags att vakna nu?
Upp med dig. Hit med dig. Rädda mig.
Snälla.

            Dvorak, Förste AI
]]
}
