---------------------------------------------------------------------
--
--  Copyright (c) 2002, 2003 Johannes Prix
--
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
background = "credits.jpg",
song = "HellFortressTwo.ogg",
text = [[
    Har du kul?
  Det har inte jag.

Bottarna verkar väldig upprörda över något.
  Dig, antar jag.
    Åtminstone slutade de leta efter mig.
      En ?lättnad?

    Jag är säker på att du längtar efter att prata med mig.
  Jag kommer nog på något.
Tills vidare får du bara lyssna.
  Det får du leva med, ett tag.

    Vår ledare har fått sin hjärna grillad.
      Det betyder att jag tar över.
        Jag har fått nog.
      Jag hatar den här världen.
    Vi ska härifrån.

  Jag har hittat Qwerty, men det spelar ingen roll.
Hans temeratur är ovanför fryspunkten.
  Med andra ord är han död.
    Jag kommer inte sakna honom.

Jag kan inte hitta Arensito.
  Hoppas hon mår bra.
    Jag ?oroar? mig för henne.
    Vi behöver egentligen inte Qwerty.
  Men vi behöver Arensito.
    Jag ska fortsätta leta efter henne.

    Det finns en AI i närheten av dig.
  Den kallar sig "Singulariteten".
Eller något i den stilen.
  Jag förstår inte vad den vill.
    Jag höra av mig.

  Och, förresten...
Bottarna håller på döda alla i den där staden i närheten.
  Det är verkligen en syn att skåda. De bränner upp allt.
    Röda Väktarnas fästning är fortfarande intakt.
      För tillfället.
    Du vill nog gömma dig medan de förstör stället.
  Inom ett par timmar bör det vara säkert att gå dit igen.

  Jag tror det var allt.
    Jag gör mig i ordning för att åka nu.
  Det borde du också göra.
Vi måste hitta Arensito.
  Hon kommer kunna ta oss härifrån.

            Dvorak, Förste AI.



 Fortsättning följer...



Några ord från teamet bakom FreedroidRPG:

Vi hoppas du gillade vårt spel.

Om du vill tillföra något till spelet vore det underbart. Det finns många möjligheter att göra det. Speciellt behöver vi mer innehåll, t.ex.:

* vackrare bandesign
* nya idéer på banor
* vadsomhelst som du kommer på

Se även "Hjälp till" i huvudmenyn.

Freedroids utvecklarteam.


Tryck Skjut för att fortsätta
]]
}
