---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "TheBeginning.ogg",
text = [[
Tu essaies de hacker quelqu'un, hein ?
Tu ne te rappelles pas comment le faire ?
Idiot. Ne fait pas surchauffer ton cerveau avant d'essayer de hacker.
Voilà un cours rapide pour te rafraîchir la mémoire.

Premièrement, n'essaie pas de hacker si tu es en train de mourir.
Si tu perds, tu vas recevoir un gentil électro-choc.
Il ne te tuera pas à moins d'être presque mort, mais il fera mal.
Beaucoup.

Il y a deux étapes dans un hack.
Premièrement, choisis la carte de circuit que tu considères être la meilleure.
Une est jaune et l'autre est violette.
Appuie juste sur gauche ou droite sur ton clavier pour choisir.
Tu as environ 10 secondes avant que le robot ne te remarque.
Prends le circuit que tu trouves le plus avantageux.

La deuxième étape est de créer des connexions dans les processeurs.
Dans le cas où tu te poses la question, ce sont les choses au centre.

Parce que les robots sont bogués, quelques processeurs sont de ton côté.
Tu n'as qu'un nombre limité d'attaques, fais qu'elles comptent.
Choisis le câble que tu veux utiliser pour attaquer les processeurs.
Appuie haut et bas sur ton clavier.
Tu peux aussi utiliser la molette si tu en as une.
Quant tu t'es décidé, appuie sur la touche espace.
Tout ce qui est au bout des connexions va t'appartenir.
Bien évidement, le robot ne vas pas rester là sans rien faire.
Il va essayer de regagner le contrôle et créer des connexions lui aussi.

Après un court temps, tout est fini.
Si tu contrôles le plus de processeurs à ce moment, le robot t'appartient.
Sinon, tu reçois une électrocution gratuite, style MegaSys.

Les connexions à l'intérieur des robots sont parfois un peu étranges.
Tu vas devoir apprendre les détails par toi-même.
Je ne vais pas risquer ma sécurité en t'avantageant.
Trop de robots autour pour continuer la transmission pendant trop longtemps.

Oh, et une requête.
La prochaine fois que tu décides de te faire sauter le cerveau...
Prends les manuels avec toi durant ton sommeil de stase.
Je pourrais ne pas être là pour te sauver la prochaine fois.

            Dvorak, Première IA.
]]
}
