---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
background = "credits.jpg",
song = "TheBeginning.ogg",
text = [[
            COME CONTRIBUIRE

FreedroidRPG è un software e un'opera d'arte completamente gratuita.
E' sviluppata esclusivamente da volontari nel loro tempo libero.

FreedroidRPG confida su questi contributi per diventare un gioco migliore.
Se sei interessato a contribuire ma non sei sicuro come, ecco una lista di cose:

TESTING E BUG REPORTING:

Abbiamo bisogno di persone per provare il gioco e riportare qualsiasi cosa non funzioni correttamente o sembra essere instabile. Questo include cose minori come errori di ortografia e simili. Il compito dei test sta crescendo con la dimensione di FreedroidRPG. Abbiamo bisogno del tuo aiuto.
Non esitare ad inviare dei rattoppi !

CREATORE DI MAPPE:

Stiamo cercando persone che vogliamo creare mappe per noi. C'è un editor delle mappe all'interno del gioco. Provalo, e se fai qualcosa di interessante assicurati di tornare da noi.

DOCUMENTAZIONE:

Siamo attualmente mancanti di documentazione. Avremmo bisogno di documentazione per l'utente finale relativi al gioco e al suo editor dei livelli, così come documentazione per gli sviluppatori. Richiesta buona abilità di scrittura.

EFFETTI SONORI:

Siamo sicuri che potremmo usare alcuni effetti sonori. Se vuoi contribuire un po' a una giusta causa noi non diremo di no. :)

CONTATTI:

Se volete contribuire a qualcosa o dare qualche riscontro riguardo al gioco, puoi facilmente metterti in contatto con gli sviluppatori. Mandando una email al seguente indirizzo:
freedroid-discussion@lists.sourceforge.net

Oppure, se preferisci, potresti fare un salto nel nostro IRC channel (#freedroid on irc.libera.chat). Tutti sono invitati. Porta i tuoi amici!

Grazie,

            Il Team sviluppatori di FreedroidRPG.
]]
}
