---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "Bleostrada.ogg",
voice_acting = "StartOfGame.ogg",
preroll_text = 3,
postroll_text = 3,
text = [[
Quelle belle journée.
Oui, je suis un peu sarcastique. 
Toute la planète est en feu.
Des milliers de personnes ont été anéanties.
Azerty et Arensito ne répondent plus. 

Ah oui, j'avais presque oublié. 
Ces satanés robots sont sur le point de me trouver, moi aussi. 
Cette situation ne me plaît pas. Pas du tout. 
Je pense que je vais me faire passer pour un simple rocher, une fois de plus. 
Tu ne penses pas que ça serait le bon moment pour te réveiller? 
Debout là-dedans ! Viens me sauver les fesses ! 
S'il te plaît.

            Dvorak, Première IA
]]
}
