---------------------------------------------------------------------
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "Bleostrada.ogg",
voice_acting = "StartOfGame.ogg",
preroll_text = 3,
postroll_text = 3,
text = [[
Che grande giorno.
Si, devo essere sarcastico.
L'intero pianeta è in fiamme.
Migliaia di persone sono morte.
Qwerty e Arensito non danno risposta.

Ah, si, quasi dimenticavo.
Pure i robot sanguinari sono in procinto di trovarmi.
Non sono molto felice di questo. Non affatto felice.
Penso di dover fingere di essere una roccia, ancora una volta.
Non pensi che sarebbe un gran momento per svegliarsi ?
Alzati. Vieni qui. Salvami il culo.
Per favore.

            Dvorak, Prima AI
]]
}
