---------------------------------------------------------------------
--
--  Copyright (c) 2002, 2003 Johannes Prix
--  Copyright (c) 2003 Pete Spicer
--
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "Bleostrada.ogg",
text = [[
            IRÁNYÍTÁS

MOZGÁS:

A játékot az egérrel lehet vezérelni. Kattints bal gombbal a helyre, ahova mennél. Tartsd lenyomva a gombot a folyamatosan abba az irányba mozgáshoz. A CTRL gomb lenyomásakor futni fogsz.

TÁMADÁS:

Az ellenfelekre bal kattintáskor Tux közelebb megy a bothoz, és elkezdi támadni a jelenlegi fegyverrel. Ha a jelenlegi fegyver lőfegyver, akkor Tux megáll, és tüzet nyit a botra.

KÜLÖNLEGES FUNKCIÓK:

Használj a jobb kattintást, hogy aktiváld a jelenleg kiválasztott képességet/programot.

Alapértelmezett gombok (a legtöbb gomb átállítható a játékon belül kiosztásban – F1)

  Escape … Főmenü megjelenítése
  F1… Kiosztás megjelenítése
  F2 … Teljes képernyő bekapcsolása (csak Linux)
  F3 … Gyors mentés
  F4 … Gyors betöltés
  F5-F12 … Programok gyors kiválasztása 1-től 8-ig

  I … Felszerelés panel
  C … Karakter panel
  S … Képességek/Program panel
  Szóköz … Minden nyitott panel bezárása
  Q … Küldetésnapló
  0-9 … Felszerelés gyors használata 0-tól 9-ig

  P … Szüneteltetés
  A nyomva tartva … Támadás ugyanabból a pozícióból
  Shift nyomva tartva … A jelenlegi célpont kiválasztva tartása mozgás közben
  Tab … Automatikus térkép bekapcsolása

  R … Fegyver újratöltése
  Ctrl nyomva tartva … Futás
  U … Állandó futás bekapcsolása

  X nyomva tartása … Tárgycímkék megjelenítése a földön
  Z … Tárgycímkék megjelenítésének bekapcsolása
  T … Falak átlátszóvá válásának bekapcsolása ha Tux közel megy (csak OpenGL)

ÁTVÉTEL/CSEVEGÉS

A barátságos droiddal beszélgetéshez elég ha rákattintasz. Az ellenséges bot vezérlésének átvételéhez válaszd ki az átvétel/csevegés képességet a képességek képernyőn, aztán kattints a jobb gombra az átvétel megkezdéséhez.

Az átvételi játékhoz az egérgörgőt vagy a kurzorbillentyűket használhatod.

Esetleg érdekelhet az Oktatójáték, amelyet a főmenüből tudsz elérni.

Ha elakadtál, és segítéségre van szükséged, akkor gyere fel a #freedroid csatornára az irc.libera.chat oldalon, és kérj segítséget.

Ennyi, jó játékot.



Nyomd meg a bal egérgombot a játék indításához.
]]
}
