---------------------------------------------------------------------
--
--  Copyright (c) 2002, 2003 Johannes Prix
--  Copyright (c) 2003 Pete Spicer
--
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
song = "Bleostrada.ogg",
text = [[
            CONTROLLI

MOVIMENTO:

Il gioco è controllato con il mouse. Click sinistro sulle posizioni che si desidera spostare. Tenere premuto il pulsante per continuare a muoversi in quella direzione. Con CTRL premuto puoi correre.

ATTACCO:

Tasto sinistro del mouse su un nemico causerà Tux venire vicino il robot e iniziano ad attaccare con l'arma. Se l'attuale arma è una pistola Tux stare fermo e sparera il robot.

FUNZIONI SPECIALI:

Usa il tasto destro per attivare l' abilità/programma attualmente selezionato.

Tasti Normali (la maggior parte dei tasti possono essere riassegnata nel game con il tasto - F1)

  Uscita ... Mostra il menu principale
  F1 ... Mostra la keychart
  F2 ... Attiva schermo pieno (solo Linux)
  F3 ... Quicksave
  F4 ... Caricamento rapido
  F5-F12 ... Rapida selezione programmi da 1 a 8

  I ... Pannello inventario
  C ... Pannello personaggi
  S ... Pannello abilità/programma
  Spazio ... Chiudi tutti i pannelli aperti
  Q ... Registro delle ricerche
  0-9 ... Rapido inventario degli articoli 0-9

  P ... Pausa
  Premi A ... Attacca mentre rimani nella stessa posizione
  Premi Shift ... Mantieni l'obiettivo corrente selezionato quando ti muovi
  Tab        ... Toggle automap

  R ... Ricarica l'arma
  Premi Ctrl ... Corri
  U ... Attiva/disattiva sempre la corsa

  Premi X ... Mostra le etichette degli oggetti sul terreno
  Z ... Attiva/disattiva il mostra etichette degli oggetti sul terreno
  T          ... Toggle walls becoming transparent when Tux approaches (OpenGL only)

TAKEOVER/CHAT

Per chattare con un droide amichevole, è sufficiente cliccare su di lui. To take over a hostile bot, select the takeover/chat skill from the skills screen, then click the right mouse button to initiate takeover.

Per la takeover partita, è possibile utilizzare la rotellina del mouse o i tasti cursore.

Se sei interessato a giocare il Tutorial, è possibile accederelo dal menu principale.

Se si sono bloccati e hai bisogno di aiuto, vieni discutere a #freedroid su irc.libera.chat e chiedere aiuto.

Questo è tutto, buono gioco.



Premere il tasto sinistro del mouse per iniziare a giocare.
]]
}
