---------------------------------------------------------------------
--
--  Copyright (c) 2002, 2003 Johannes Prix
--
-- This file is part of Freedroid
--
-- Freedroid is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- Freedroid is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Freedroid; see the file COPYING. If not, write to the
-- Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-- MA 02111-1307 USA
----------------------------------------------------------------------

title_screen{
background = "credits.jpg",
song = "HellFortressTwo.ogg",
voice_acting = "EndOfAct.ogg",
preroll_text = 2,
postroll_text = 5,
text = [[
    Hast du Spaß gehabt?
  Ich nicht.

Die Robos scheinen sehr verärgert zu sein.
Ich glaube, sie regen sich über dich auf.
Wenigstens sehen sie mich nicht mehr an.
Was für eine…? Erleichterung?

Es befindet sich eine KI in deiner Umgebung.
Sie nennt sich selbst "Singularität".
Oder so.
Ich kann nicht verstehen, was sie will.
Ich werde dich weiterhin informieren.

Oh, und nebenbei…
Ich warte auf dich.
Ich habe mich keinen Zentimeter bewegt, seitdem du aufgewacht bist.
Jetzt wo deine geliebte Stadt sicher ist…
…Wäre es nicht nett, mich auch zu retten?

            Dvorak, die erste KI.



=== ENDE DES 1. KAPITELS ===

]]
}
